summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEric Haszlakiewicz <erh+git@nimenees.com>2012-04-24 21:54:07 -0500
committerEric Haszlakiewicz <erh+git@nimenees.com>2012-04-24 21:54:07 -0500
commit4e000a65e671588749a670c5d954ffa8d2d41b0a (patch)
tree257279a5b0edd7b7abdfc0b1da03089392329ef5
parent0f8c53450291ab4d108cf5cb83104d1fbe39a002 (diff)
downloadjson-c-4e000a65e671588749a670c5d954ffa8d2d41b0a.tar.gz
Since we already use a local json_bool type, replace any stdbool.h usage with
that, since not all environments actually have a stdbool.h to use.
-rw-r--r--json_object.c1
-rw-r--r--json_object_iterator.c3
-rw-r--r--json_object_iterator.h5
3 files changed, 3 insertions, 6 deletions
diff --git a/json_object.c b/json_object.c
index 842ca22..84af414 100644
--- a/json_object.c
+++ b/json_object.c
@@ -25,7 +25,6 @@
#include "json_object.h"
#include "json_object_private.h"
#include "json_util.h"
-#include "json_tokener.h"
#if !HAVE_STRNDUP
char* strndup(const char* str, size_t n);
diff --git a/json_object_iterator.c b/json_object_iterator.c
index 7191b53..7066649 100644
--- a/json_object_iterator.c
+++ b/json_object_iterator.c
@@ -16,7 +16,6 @@
*/
#include <stddef.h>
-#include <stdbool.h>
#include "json.h"
#include "json_object_private.h"
@@ -139,7 +138,7 @@ json_object_iter_peek_value(const struct json_object_iterator* iter)
/**
* ****************************************************************************
*/
-bool
+json_bool
json_object_iter_equal(const struct json_object_iterator* iter1,
const struct json_object_iterator* iter2)
{
diff --git a/json_object_iterator.h b/json_object_iterator.h
index 3221a15..f6e7ca6 100644
--- a/json_object_iterator.h
+++ b/json_object_iterator.h
@@ -24,7 +24,6 @@
#define JSON_OBJECT_ITERATOR_H
#include <stddef.h>
-#include <stdbool.h>
#ifdef __cplusplus
extern "C" {
@@ -223,11 +222,11 @@ json_object_iter_peek_value(const struct json_object_iterator* iter);
* different JSON Object instances are passed, bad things
* will happen!
*
* @return bool non-zero if iterators are equal (i.e., both
* reference the same name/value pair or are both at
* "end"); zero if they are not equal.
*/
-bool
+json_bool
json_object_iter_equal(const struct json_object_iterator* iter1,
const struct json_object_iterator* iter2);
@@ -223,11 +222,11 @@ json_object_iter_peek_value(const struct json_object_iterator* iter);
* will happen!
*
- * @return bool non-zero if iterators are equal (i.e., both
+ * @return json_bool non-zero if iterators are equal (i.e., both
* reference the same name/value pair or are both at
* "end"); zero if they are not equal.